@@ -55,6 +55,13 @@ typedef enum
 	EV_DOCUMENT_MODE_PRESENTATION = EV_DOCUMENT_MODE_FULL_SCREEN /* Will these be different? */
 } EvDocumentMode;
 
+typedef enum
+{
+	EV_DOCUMENT_CONTAINS_JS_UNKNOWN,
+	EV_DOCUMENT_CONTAINS_JS_NO,
+	EV_DOCUMENT_CONTAINS_JS_YES
+} EvDocumentContainsJS;
+
 typedef enum
 {
 	EV_DOCUMENT_UI_HINT_HIDE_TOOLBAR = 1 << 0,
@@ -100,10 +107,12 @@ typedef enum
 	EV_DOCUMENT_INFO_N_PAGES = 1 << 14,
 	EV_DOCUMENT_INFO_SECURITY = 1 << 15,
 	EV_DOCUMENT_INFO_PAPER_SIZE = 1 << 16,
-	EV_DOCUMENT_INFO_LICENSE = 1 << 17
+	EV_DOCUMENT_INFO_LICENSE = 1 << 17,
+	EV_DOCUMENT_INFO_CONTAINS_JS = 1 << 18
 
 } EvDocumentInfoFields;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 struct _EvDocumentInfo
 {
 	char *title;
@@ -125,10 +134,12 @@ struct _EvDocumentInfo
 	double paper_height;
 	double paper_width;
 	EvDocumentLicense *license;
+	EvDocumentContainsJS contains_js; /* wheter it contains any javascript */
 
 	/* Mask of all the valid fields */
 	guint fields_mask;
 };
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 GType           ev_document_info_get_type (void) G_GNUC_CONST;
 EvDocumentInfo *ev_document_info_copy     (EvDocumentInfo *info);
